@@ -1,4 +1,4 @@
-require(pomp)
+library(pomp)
 
 dat <- '"time";"y1";"y2"
 1;-1,88442138814419;1,16694679794963
