@@ -28,9 +28,9 @@ SEXP R_Euler_Multinom (SEXP n, SEXP size, SEXP rate, SEXP dt) {
   int dim[2];
   SEXP nn, x;
   if (length(size)>1)
-    warning("reulermultinom: only the first element of 'size' is meaningful");
+    warningcall(R_NilValue,"in 'reulermultinom': only the first element of 'size' is meaningful");
   if (length(dt)>1)
-    warning("reulermultinom: only the first element of 'dt' is meaningful");
+    warningcall(R_NilValue,"in 'reulermultinom': only the first element of 'dt' is meaningful");
   PROTECT(nn = AS_INTEGER(n)); nprotect++;
   dim[0] = ntrans;
   dim[1] = INTEGER(nn)[0];
@@ -50,12 +50,12 @@ SEXP D_Euler_Multinom (SEXP x, SEXP size, SEXP rate, SEXP dt, SEXP log) {
   SEXP f;
   dim = INTEGER(GET_DIM(x));
   if (dim[0] != ntrans)
-    error("deulermultinom: 'NROW(x)' should match length of 'rate'");
+    errorcall(R_NilValue,"NROW('x') should match length of 'rate'");
   n = dim[1];
   if (length(size)>1)
-    warning("deulermultinom: only the first element of 'size' is meaningful");
+    warningcall(R_NilValue,"in 'deulermultinom': only the first element of 'size' is meaningful");
   if (length(dt)>1)
-    warning("deulermultinom: only the first element of 'dt' is meaningful");
+    warningcall(R_NilValue,"in 'deulermultinom': only the first element of 'dt' is meaningful");
   PROTECT(f = NEW_NUMERIC(n)); nprotect++;
   deulermultinom_multi(&n,&ntrans,REAL(size),REAL(rate),REAL(dt),REAL(x),INTEGER(log),REAL(f));
   UNPROTECT(nprotect);
@@ -88,4 +88,3 @@ SEXP R_GammaWN (SEXP n, SEXP sigma, SEXP deltat) {
   UNPROTECT(nprotect);
   return ans;
 }
-
